@@ -101,7 +101,8 @@ void togglePlaylistShow (GtkCheckMenuItem *checkmenuitem, Application * app);
 void togglePlaylistShowAll (GtkCheckMenuItem *checkmenuitem, Application * app);
 void togglePlaylistEdit (GtkCheckMenuItem *checkmenuitem, Application * app);
 void toggleMediaServer (GtkCheckMenuItem *radio, Application * app);
-void cb_mainview_deleted (GtkObject * w, Application * app);
+gboolean cb_mainview_delete (GtkObject *w, GdkEvent *event, Application *app);
+void cb_mainview_close (GtkObject *w, Application *app);
 gboolean cb_keyPressed (GtkWidget *, GdkEventKey * e, Application *app);
 void cb_row_activated (GtkTreeView *treeview, GtkTreePath *path, GtkTreeViewColumn *arg2, Application * app);
 void cb_playlist_edit_commit (GtkButton * button, Application * app);
@@ -119,10 +120,12 @@ void cb_playlist_prev (GtkButton * button, void *ctr);
 void cb_playlist_play (GtkButton * button, void *ctr);
 void cb_playlist_next (GtkButton * button, void *ctr);
 void cb_playlist_stop (GtkButton * button, void *ctr);
+GValue *playlist_selected (Application *app, GValue *value);
 void progressValueChanged(GtkWidget *w, Application * app);
 gboolean cb_scheduledPaint (void * p);
 gboolean cbViewAreaFullscreenMapped (GtkWidget *w, GdkEvent *, Application *a);
 void cbViewAreaFullscreenUnmapped (GtkWidget *w, Application *a);
+void cb_fullscreen_destoyed (GtkObject *o, Application *app);
 
 void save_locationbar (Application * app);
 gboolean locationbarGainFocus (GtkWidget *, GdkEventFocus *, Application *app);
