@@ -40,7 +40,7 @@ const short id_node_enclosure = 205;
 class KMPLAYER_NO_EXPORT Rss : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Rss (NodePtr & d) : Mrl (d, id_node_rss) {}
-    NodePtr childFromTag (const String & tag);
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "rss"; }
     bool expose () const { return false; }
 };
@@ -48,7 +48,7 @@ public:
 class KMPLAYER_NO_EXPORT Channel : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Channel (NodePtr & d) : Mrl (d, id_node_channel) {}
-    NodePtr childFromTag (const String & tag);
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "channel"; }
     PlayType playType () { return play_type_none; }
     void closed ();
@@ -59,7 +59,7 @@ class KMPLAYER_NO_EXPORT Item : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Item (NodePtr & d)
         : Mrl (d, id_node_item), timer (NULL) {}
-    NodePtr childFromTag (const String & tag);
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "item"; }
     PlayType playType () { return cached_play_type; }
     Mrl * linkNode ();
