@@ -299,8 +299,8 @@ KDE_NO_EXPORT void Node::replaceChild (NodePtr _new, NodePtr old) {
     old->m_parent = 0L;
 }
 
-NodePtr Node::childFromTag (const String &) {
-    return NodePtr ();
+Node *Node::childFromTag (const String &) {
+    return NULL;
 }
 
 KDE_NO_EXPORT void Node::characterData (const String & s) {
@@ -643,11 +643,11 @@ String Mrl::absolutePath () {
     return path.isEmpty () ? src : path;
 }
 
-NodePtr Mrl::childFromTag (const String & tag) {
+Node *Mrl::childFromTag (const String & tag) {
     Node * elm = fromXMLDocumentTag (m_doc, tag);
     if (elm)
         return elm;
-    return NodePtr ();
+    return NULL;
 }
 
 Mrl * Mrl::linkNode () {
@@ -658,13 +658,17 @@ Mrl * Mrl::mrl () {
     return this;
 }
 
-void Mrl::endOfFile () {
-    if (state == state_deferred &&
-            !isPlayable () && firstChild ()) { // if backend added child links
-        state = state_activated;
-        firstChild ()->activate ();
-    } else
-        finish ();
+void *Mrl::message (MessageType msg, void *content) {
+    if (MsgMediaFinished == msg) {
+        if (state == state_deferred &&
+                !isPlayable () && firstChild ()) {//if backend added child links
+            state = state_activated;
+            firstChild ()->activate ();
+        } else
+            finish ();
+        return NULL;
+    }
+    return Node::message (msg, content);
 }
 
 void Mrl::activate () {
@@ -847,11 +851,11 @@ Node *Document::getElementById (Node *n, const String & id, bool inter) {
     return getElementByIdImpl (n, id, inter);
 }
 
-KDE_NO_EXPORT NodePtr Document::childFromTag (const String & tag) {
+KDE_NO_EXPORT Node *Document::childFromTag (const String & tag) {
     Node * elm = fromXMLDocumentTag (m_doc, tag);
     if (elm)
         return elm;
-    return 0L;
+    return NULL;
 }
 
 void Document::dispose () {
@@ -1214,7 +1218,7 @@ DarkNode::DarkNode (NodePtr & d, const String & n, short id)
  : Element (d, id), name (n) {
 }
 
-NodePtr DarkNode::childFromTag (const String & tag) {
+Node *DarkNode::childFromTag (const String & tag) {
     return new DarkNode (m_doc, tag);
 }
 
@@ -1270,6 +1274,10 @@ void Visitor::visit (Element *elm) {
     visit (static_cast <Node *> (elm));
 }
 
+void Visitor::visit (TextNode *text) {
+    visit (static_cast <Node *> (text));
+}
+
 //-----------------------------------------------------------------------------
 
 namespace KMPlayer {
