@@ -60,12 +60,10 @@
 
 struct GnomeVFSURI;
 
-namespace {
-    class GnomeVFSFilePrivate;
-}
-
 namespace KMPlayer {
 
+class GnomeVFSFilePrivate;
+
 /**
  * Type meant for screen coordinates
  */
@@ -264,10 +262,10 @@ public:
     StringTmpl <T> upper () const;
     StringTmpl <T> stripWhiteSpace () const;
     static StringTmpl <T> number (int nr);
-    bool hasPrefix (const StringTmpl <T> & prefix) const;
-    bool hasSuffix (const StringTmpl <T> & suffix) const;
-    int find (const StringTmpl <T> & needle) const;
-    int findRev (const StringTmpl <T> & needle) const;
+    bool startsWith (const StringTmpl <T> & prefix) const;
+    bool endsWith (const StringTmpl <T> & suffix) const;
+    int indexOf (const StringTmpl <T> & needle) const;
+    int lastIndexOf (const StringTmpl <T> & needle) const;
     StringTmpl <T> &replace (Char c1, Char c2);
     bool isEmpty () const;
     bool isNull () const;
@@ -333,10 +331,10 @@ public:
     GLibString stripWhiteSpace () const;
     static GLibString fill (Char ch, int length);
     static GLibString number (int nr);
-    bool hasPrefix (const GLibString & prefix) const;
-    bool hasSuffix (const GLibString & suffix) const;
-    int find (const GLibString & needle) const;
-    int findRev (const GLibString & needle) const;
+    bool startsWith (const GLibString & prefix) const;
+    bool endsWith (const GLibString & suffix) const;
+    int indexOf (const GLibString & needle) const;
+    int lastIndexOf (const GLibString & needle) const;
     GLibString replace (Char c1, Char c2) const;
     bool isEmpty () const;
     GLibString mid (const int index, unsigned length=(unsigned)-1) const;
@@ -1288,23 +1286,23 @@ inline StringTmpl <T> StringTmpl<T>::number (int nr) {
 }
 
 template <class T>
-inline bool StringTmpl<T>::hasPrefix (const StringTmpl <T> & prefix) const {
-    return string.hasPrefix (prefix.string);
+inline bool StringTmpl<T>::startsWith (const StringTmpl <T> & prefix) const {
+    return string.startsWith (prefix.string);
 }
 
 template <class T>
-inline bool StringTmpl<T>::hasSuffix (const StringTmpl <T> & suffix) const {
-    return string.hasSuffix (suffix.string);
+inline bool StringTmpl<T>::endsWith (const StringTmpl <T> & suffix) const {
+    return string.endsWith (suffix.string);
 }
 
 template <class T>
-inline int StringTmpl<T>::find (const StringTmpl <T> & needle) const {
-    return string.find (needle.string);
+inline int StringTmpl<T>::indexOf (const StringTmpl <T> & needle) const {
+    return string.indexOf (needle.string);
 }
 
 template <class T>
-inline int StringTmpl<T>::findRev (const StringTmpl <T> & needle) const {
-    return string.findRev (needle.string);
+inline int StringTmpl<T>::lastIndexOf (const StringTmpl <T> & needle) const {
+    return string.lastIndexOf (needle.string);
 }
 
 template <class T>
@@ -2159,8 +2157,8 @@ KMPLAYER_NO_CDTOR_EXPORT inline GColor::GColor (const GColor & c)
 
 KMPLAYER_NO_EXPORT inline void GColor::clear () {
     if (m_color) {
-        gdk_colormap_free_colors (gdk_colormap_get_system (), m_color, 1);
-        //g_free (m_color); // ??
+        //gdk_colormap_free_colors (gdk_colormap_get_system (), m_color, 1);
+        gdk_color_free (m_color); // ??
         m_color = 0L;
     }
 }
